// Package publishserviceapi provides primitives to interact with the openapi HTTP API.
//
// Code generated by github.com/deepmap/oapi-codegen version v1.9.1 DO NOT EDIT.
package publishserviceapi

import (
	externalRef0 "oransc.org/nonrtric/plt/capif/internal/readonly/common"
	externalRef1 "oransc.org/nonrtric/plt/capif/internal/readonly/common29571"
)

// Defines values for CommunicationType.
const (
	CommunicationTypeREQUESTRESPONSE CommunicationType = "REQUEST_RESPONSE"

	CommunicationTypeSUBSCRIBENOTIFY CommunicationType = "SUBSCRIBE_NOTIFY"
)

// Defines values for DataFormat.
const (
	DataFormatJSON DataFormat = "JSON"
)

// Defines values for Operation.
const (
	OperationDELETE Operation = "DELETE"

	OperationGET Operation = "GET"

	OperationPATCH Operation = "PATCH"

	OperationPOST Operation = "POST"

	OperationPUT Operation = "PUT"
)

// Defines values for Protocol.
const (
	ProtocolHTTP11 Protocol = "HTTP_1_1"

	ProtocolHTTP2 Protocol = "HTTP_2"
)

// Defines values for SecurityMethod.
const (
	SecurityMethodOAUTH SecurityMethod = "OAUTH"

	SecurityMethodPKI SecurityMethod = "PKI"

	SecurityMethodPSK SecurityMethod = "PSK"
)

// AefProfile defines model for AefProfile.
type AefProfile struct {
	// Identifier of the API exposing function
	AefId string `json:"aefId"`

	// Possible values are - JSON: JavaScript Object Notation
	DataFormat *DataFormat `json:"dataFormat,omitempty"`

	// Domain to which API belongs to
	DomainName *string `json:"domainName,omitempty"`

	// Interface details
	InterfaceDescriptions *[]InterfaceDescription `json:"interfaceDescriptions,omitempty"`

	// Possible values are - HTTP_1_1: HTTP version 1.1 - HTTP_2: HTTP version 2
	Protocol *Protocol `json:"protocol,omitempty"`

	// Security methods supported by the AEF
	SecurityMethods *[]SecurityMethod `json:"securityMethods,omitempty"`

	// API version
	Versions []Version `json:"versions"`
}

// Possible values are - REQUEST_RESPONSE: The communication is of the type request-response - SUBSCRIBE_NOTIFY: The communication is of the type subscribe-notify
type CommunicationType string

// CustomOperation defines model for CustomOperation.
type CustomOperation struct {
	// Possible values are - REQUEST_RESPONSE: The communication is of the type request-response - SUBSCRIBE_NOTIFY: The communication is of the type subscribe-notify
	CommType CommunicationType `json:"commType"`

	// it is set as {custOpName} part of the URI structure for a custom operation without resource association as defined in subclause 4.4 of 3GPP TS 29.501.
	CustOpName string `json:"custOpName"`

	// Text description of the custom operation
	Description *string `json:"description,omitempty"`

	// Supported HTTP methods for the API resource. Only applicable when the protocol in AefProfile indicates HTTP.
	Operations *[]Operation `json:"operations,omitempty"`
}

// Possible values are - JSON: JavaScript Object Notation
type DataFormat string

// InterfaceDescription defines model for InterfaceDescription.
type InterfaceDescription struct {
	// string identifying a Ipv4 address formatted in the "dotted decimal" notation as defined in IETF RFC 1166.
	Ipv4Addr *externalRef0.Ipv4Addr `json:"ipv4Addr,omitempty"`

	// string identifying a Ipv6 address formatted according to clause 4 in IETF RFC 5952. The mixed Ipv4 Ipv6 notation according to clause 5 of IETF RFC 5952 shall not be used.
	Ipv6Addr *externalRef0.Ipv6Addr `json:"ipv6Addr,omitempty"`

	// Unsigned integer with valid values between 0 and 65535.
	Port *externalRef0.Port `json:"port,omitempty"`

	// Security methods supported by the interface, it take precedence over the security methods provided in AefProfile, for this specific interface.
	SecurityMethods *[]SecurityMethod `json:"securityMethods,omitempty"`
}

// Possible values are - GET: HTTP GET method - POST: HTTP POST method - PUT: HTTP PUT method - PATCH: HTTP PATCH method - DELETE: HTTP DELETE method
type Operation string

// Possible values are - HTTP_1_1: HTTP version 1.1 - HTTP_2: HTTP version 2
type Protocol string

// PublishedApiPath defines model for PublishedApiPath.
type PublishedApiPath struct {
	// A list of CCF identifiers where the service API is already published.
	CcfIds *[]string `json:"ccfIds,omitempty"`
}

// Resource defines model for Resource.
type Resource struct {
	// Possible values are - REQUEST_RESPONSE: The communication is of the type request-response - SUBSCRIBE_NOTIFY: The communication is of the type subscribe-notify
	CommType CommunicationType `json:"commType"`

	// it is set as {custOpName} part of the URI structure for a custom operation associated with a resource as defined in subclause 4.4 of 3GPP TS 29.501.
	CustOpName *string `json:"custOpName,omitempty"`

	// Text description of the API resource
	Description *string `json:"description,omitempty"`

	// Supported HTTP methods for the API resource. Only applicable when the protocol in AefProfile indicates HTTP.
	Operations *[]Operation `json:"operations,omitempty"`

	// Resource name
	ResourceName string `json:"resourceName"`

	// Relative URI of the API resource, it is set as {apiSpecificResourceUriPart} part of the URI structure as defined in subclause 4.4 of 3GPP TS 29.501.
	Uri string `json:"uri"`
}

// Possible values are - PSK: Security method 1 (Using TLS-PSK) as described in 3GPP TS 33.122 - PKI: Security method 2 (Using PKI) as described in 3GPP TS 33.122 - OAUTH: Security method 3 (TLS with OAuth token) as described in 3GPP TS 33.122
type SecurityMethod string

// ServiceAPIDescription defines model for ServiceAPIDescription.
type ServiceAPIDescription struct {
	// AEF profile information, which includes the exposed API details (e.g. protocol).
	AefProfiles *[]AefProfile `json:"aefProfiles,omitempty"`

	// API identifier assigned by the CAPIF core function to the published service API. Shall not be present in the HTTP POST request from the API publishing function to the CAPIF core function. Shall be present in the HTTP POST response from the CAPIF core function to the API publishing function and in the HTTP GET response from the CAPIF core function to the API invoker (discovery API).
	ApiId *string `json:"apiId,omitempty"`

	// API name, it is set as {apiName} part of the URI structure as defined in subclause 4.4 of 3GPP TS 29.501.
	ApiName      string                          `json:"apiName"`
	ApiSuppFeats *externalRef1.SupportedFeatures `json:"apiSuppFeats,omitempty"`

	// CAPIF core function identifier.
	CcfId *string `json:"ccfId,omitempty"`

	// Text description of the API
	Description        *string                         `json:"description,omitempty"`
	PubApiPath         *PublishedApiPath               `json:"pubApiPath,omitempty"`
	ServiceAPICategory *string                         `json:"serviceAPICategory,omitempty"`
	ShareableInfo      *ShareableInformation           `json:"shareableInfo,omitempty"`
	SupportedFeatures  *externalRef1.SupportedFeatures `json:"supportedFeatures,omitempty"`
}

// ShareableInformation defines model for ShareableInformation.
type ShareableInformation struct {
	// List of CAPIF provider domains to which the service API information to be shared.
	CapifProvDoms *[]string `json:"capifProvDoms,omitempty"`

	// Set to "true" indicates that the service API and/or the service API category can be shared to the list of CAPIF provider domain information. Otherwise set to "false".
	IsShareable bool `json:"isShareable"`
}

// Version defines model for Version.
type Version struct {
	// API major version in URI (e.g. v1)
	ApiVersion string `json:"apiVersion"`

	// Custom operations without resource association.
	CustOperations *[]CustomOperation     `json:"custOperations,omitempty"`
	Expiry         *externalRef1.DateTime `json:"expiry,omitempty"`

	// Resources supported by the API.
	Resources *[]Resource `json:"resources,omitempty"`
}

// Identification of the API publishing function.
type ApfId string

// String identifying an individual published service API.
type ServiceApiId string

// PostApfIdServiceApisJSONBody defines parameters for PostApfIdServiceApis.
type PostApfIdServiceApisJSONBody ServiceAPIDescription

// PutApfIdServiceApisServiceApiIdJSONBody defines parameters for PutApfIdServiceApisServiceApiId.
type PutApfIdServiceApisServiceApiIdJSONBody ServiceAPIDescription

// PostApfIdServiceApisJSONRequestBody defines body for PostApfIdServiceApis for application/json ContentType.
type PostApfIdServiceApisJSONRequestBody PostApfIdServiceApisJSONBody

// PutApfIdServiceApisServiceApiIdJSONRequestBody defines body for PutApfIdServiceApisServiceApiId for application/json ContentType.
type PutApfIdServiceApisServiceApiIdJSONRequestBody PutApfIdServiceApisServiceApiIdJSONBody
